@@ -1,5 +1,5 @@
 import json
-import numpy as np
+import cupy as np
 import matplotlib.pyplot as plt
 import seaborn as sns
 from scipy import stats
