@@ -1,4 +1,4 @@
-import numpy as np
+import cupy as np
 
 from odeestimatorpy.data_generator.noise.noise_generator import NoiseGenerator
 
