@@ -1,5 +1,5 @@
 from scipy.integrate import solve_ivp
-import numpy as np
+import cupy as np
 
 from odeestimatorpy.models.ode_model_base import ODEModelBase
 
