@@ -1,6 +1,6 @@
 from typing import Callable
 
-import numpy as np
+import cupy as np
 
 from abc import ABC, abstractmethod
 
