@@ -1,4 +1,4 @@
-import numpy as np
+import cupy as np
 
 from scipy.linalg import block_diag
 from sympy import Eq, lambdify
