@@ -1,5 +1,5 @@
 # General value generation methods
-import numpy as np
+import cupy as np
 
 def generate_random_values(num_variables, lower_bound=0, upper_bound=1):
     return np.random.uniform(lower_bound, upper_bound, num_variables).tolist()
