@@ -3,7 +3,7 @@ import json
 import matplotlib.pyplot as plt
 import os
 
-import numpy as np
+import cupy as np
 import sympy
 import yaml
 
